@@ -9,14 +9,16 @@
 
 #include "blinken.h"
 
+#include "blinken_version.h"
+
 #include <kaboutdata.h>
 #include <klocalizedstring.h>
 #include <KCrash>
 #include <KDBusService>
 #include <kdelibs4configmigrator.h>
 
-#include <qapplication.h>
-#include <qcommandlineparser.h>
+#include <QApplication>
+#include <QCommandLineParser>
 
 #include <QFontDatabase>
 #include <QFontInfo>
@@ -27,7 +29,7 @@ int main(int argc, char *argv[])
 	KLocalizedString::setApplicationDomain("blinken");
 
 	QApplication app(argc, argv);
-	KAboutData about(QStringLiteral("blinken"), i18n("Blinken"), QStringLiteral("0.4"), i18n("A memory enhancement game"), KAboutLicense::GPL, i18n("© 2005-2007 Albert Astals Cid\n© 2005-2007 Danny Allen"));
+	KAboutData about(QStringLiteral("blinken"), i18n("Blinken"), QStringLiteral(BLINKEN_VERSION_STRING), i18n("A memory enhancement game"), KAboutLicense::GPL, i18n("© 2005-2007 Albert Astals Cid\n© 2005-2007 Danny Allen"));
 	about.addAuthor(i18n("Albert Astals Cid"), i18n("Coding"), QStringLiteral("aacid@kde.org"));
 	about.addAuthor(i18n("Danny Allen"), i18n("Design, Graphics and Sounds"), QStringLiteral("danny@dannyallen.co.uk"));
 	about.addCredit(i18n("Steve Jordi"), i18n("GPL'ed his 'Steve' font so that we could use it"), QStringLiteral("steve@sjordi.com"));
